Absolute value of sample correlation between two vectors
corFunction.RdCalculates the absolute value of correlation of t and y. If either input has only one unique value, returns 0 by definition.
corFunction.RdCalculates the absolute value of correlation of t and y. If either input has only one unique value, returns 0 by definition.