Identify selection prototypes from selected clusters
getSelectionPrototypes.RdTakes in list of selected clusters and returns an integer vector of the indices of the features that were most frequently selected from each cluster
Value
An integer vector (of length equal to the number of clusters) of the indices of the feature prototypes (the features from each cluster that were selected the most often individually by the base method in cluster stability selection). In the case of a tie, the tie is broken by choosing the feature most correlated with the response in the full data set provided to css.