Get variance of noise to add to Z in order to yield proxies X with desired correlations with Z
getNoiseVar.RdGet variance of noise to add to Z in order to yield proxies X with desired correlations with Z
getNoiseVar.RdGet variance of noise to add to Z in order to yield proxies X with desired correlations with Z